/*******************************************************************************
* Copyright (c) 2007, Perforce Software, Inc.  All rights reserved.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
* 
* 1.  Redistributions of source code must retain the above copyright
*     notice, this list of conditions and the following disclaimer.
* 
* 2.  Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the
*     documentation and/or other materials provided with the distribution.
* 
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL PERFORCE 
* SOFTWARE, INC. BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
* ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR 
* TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
* THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
* DAMAGE.
*******************************************************************************/

#include "stdhdrs.h"
#include "strbuf.h"
#include "vararray.h"
#include "strdict.h"
#include "strtable.h"
#include "error.h"
#include "varlist.h"

//------------------------------------------------------------------------------
// VarList class implementation
//------------------------------------------------------------------------------


// Import variables from another VarList
void
VarList::Import( VarList *other )
{
    StrRef var, val;
    int i;

    for( i = 0; other->vars.GetVar( i, var, val ); i++ )
	vars.SetVar( var.Text(), val.Text() );

}

//
// Export variables in this list to a VarArray of strings - ready for use in 
// environ.
//
void
VarList::Export( VarArray *va )
{
    StrRef var, val;
    StrBuf t;
    for( int i = 0; vars.GetVar( i, var, val ); i++ )
    {
	t.Clear();
	t << var << "=" << val;
	va->Put( strdup( t.Text() ) );
    }
}


// Set a variable
void
VarList::SetVar( const char *var, const char *val )
{
    if( vars.GetVar( var ) )
	vars.ReplaceVar( var, val );
    else
	vars.SetVar( var, val );
}

void
VarList::SetVar( StrPtr &var, StrPtr &val )
{
    SetVar( var.Text(), val.Text() );
}

// Get the value of a variable
StrPtr *
VarList::GetVar( const char *var )
{
    return vars.GetVar( var );
}

StrPtr *
VarList::GetVar( StrPtr &var )
{
    return GetVar( var.Text() );
}

void
VarList::DeleteVar( const char *var )
{
    vars.RemoveVar( var );
}

// Debugging
void
VarList::Dump()
{
    int i;
    StrRef	var, val;
    for( i = 0; vars.GetVar( i, var, val ); i++ )
	printf( "\t%s=%s\n", var.Text(), val.Text() );
}

